import type { Config } from "tailwindcss";
const defaultTheme = require('tailwindcss/defaultTheme')

const config: Config = {
  content: [
    "./pages/**/*.{js,ts,jsx,tsx,mdx}",
    "./components/**/*.{js,ts,jsx,tsx,mdx}",
    "./sections/**/*.{js,ts,jsx,tsx,mdx}",
    "./app/**/*.{js,ts,jsx,tsx,mdx}",
    './node_modules/preline/preline.js',
  ],
  theme: {
    extend: {
      colors: {
        gray: {
          100: "#EBF1F5",
          200: "#D9E3EA",
          300: "#C5D2DC",
          400: "#9BA9B4",
          500: "#707D86",
          550: "#52485B",
          600: "#55595F",
          650: "#4c5058",
          700: "#33363A",
          800: "#25282C",
          825: "#34363A",
          850: "#383040",
          900: "#151719",
          925: "#191D24",
          950: "#000000"
        },
        purple: {
          default: "#8000FF",
          100: "#F4F4FF",
          200: "#E2E1FF",
          300: "#CBCCFF",
          400: "#ABABFF",
          500: "#8D8DFF",
          600: "#5D5DFF",
          700: "#4B4ACF",
          800: "#38379C",
          900: "#262668",
        },
        pink: {
          default: "#FF0DCA",
          500: "#D18DFF",
          550: "#8A4CC8",
          600: "#AB4FD7",
          700: "#7a2ec5",
          900: "#3C3445",
        },
        red: {
          300: "#C84C4C",
          600: "#8b2e2e"
        }
      },
      spacing: {
        "9/16": "56.25%",
        "3/4": "75%",
        "1/1": "100%",
      },
      fontFamily: {
        'primary': ['Raleway Variable', ...defaultTheme.fontFamily.sans],
        'secondary': ['Arimo Variable', ...defaultTheme.fontFamily.sans],
      },
      fontSize: {
        xs: "0.75rem",
        sm: "0.875rem",
        base: "1rem",
        lg: "1.125rem",
        xl: "1.25rem",
        "2xl": "1.5rem",
        "3xl": "2rem",
        "4xl": "2.5rem",
        "5xl": "3.25rem",
        "6xl": "4rem",
      },
      inset: {
        full: "100%",
      },
      letterSpacing: {
        tighter: "-0.02em",
        tight: "-0.01em",
        normal: "0",
        wide: "0.01em",
        wider: "0.02em",
        widest: "0.4em",
      },
      minWidth: {
        "10": "2.5rem",
      },
      scale: {
        "98": ".98",
      },
    },
  },
  plugins: [require("@tailwindcss/forms"), require("@tailwindcss/typography"), require("daisyui"),  require('preline/plugin')],
};
export default config;
